@@ -84,6 +84,7 @@ namespace khtml
   class CSSStyleSelector;
   class HTMLTokenizer;
   class Decoder;
+  class XMLTokenizer;
 }
 
 namespace KJS {
@@ -91,8 +92,10 @@ namespace KJS {
     class WindowFunc;
     class ExternalFunc;
     class JSEventListener;
+    class JSNodeFilter;
     class DOMDocument;
     class SourceFile;
+    class ScheduledAction;
 }
 
 namespace KParts
@@ -174,7 +177,7 @@ namespace KWallet
  *
  * @short HTML Browser Widget
  * @author Lars Knoll (knoll@kde.org)
- * @version $Id: khtml_part.h,v 1.248.2.1 2004/01/19 12:33:25 savernik Exp $
+ * @version $Id: khtml_part.h,v 1.248.2.4 2004/03/23 00:50:48 mueller Exp $
  *
  */
 class KHTMLPart : public KParts::ReadOnlyPart
@@ -192,6 +195,8 @@ class KHTMLPart : public KParts::ReadOnlyPart
   friend class DOM::HTMLFormElementImpl;
   friend class khtml::RenderPartObject;
   friend class KJS::Window;
+  friend class KJS::ScheduledAction;
+  friend class KJS::JSNodeFilter;
   friend class KJS::WindowFunc;
   friend class KJS::ExternalFunc;
   friend class KJS::JSEventListener;
@@ -203,7 +208,7 @@ class KHTMLPart : public KParts::ReadOnlyPart
   friend class DOM::HTMLDocumentImpl;
   friend class KHTMLPartBrowserHostExtension;
   friend class khtml::HTMLTokenizer;
-  friend class XMLTokenizer;
+  friend class khtml::XMLTokenizer;
   friend class khtml::RenderWidget;
   friend class khtml::CSSStyleSelector;
   friend class KHTMLPartIface;
@@ -282,6 +287,7 @@ public:
    */
   KParts::BrowserExtension *browserExtension() const;
   KParts::LiveConnectExtension *liveConnectExtension( const khtml::RenderPart *) const;
+  KParts::BrowserHostExtension *browserHostExtension() const;
 
   /**
    * Returns a pointer to the HTML document's view.
@@ -410,14 +416,24 @@ public:
   /**
    * Security option.
    *
-   * Specify whether only local references ( stylesheets, images, scripts, subdocuments )
-   * should be loaded. ( default false - everything is loaded, if the more specific
-   * options allow )
+   * Specify whether only file:/ or data:/ urls are allowed to be loaded without
+   * user confirmation by KHTML.
+   * ( for example referenced by stylesheets, images, scripts, subdocuments, embedded elements ).
+   *
+   * This option is mainly intended for enabling the "mail reader mode", where you load untrusted
+   * content with a file:/ url.
+   *
+   * Please note that enabling this option currently automatically disables Javascript, 
+   * Java and Plugins support. This might change in the future if the security model
+   * is becoming more sophisticated, so don't rely on this behaviour.
+   *
+   * ( default false - everything is loaded unless forbidden by KApplication::authorizeURLAction).
    */
   void setOnlyLocalReferences( bool enable );
 
   /**
-   * Returns whether references should be loaded ( default false )
+   * Returns whether only file:/ or data:/ references are allowed 
+   * to be loaded ( default false ). @see setOnlyLocalReferences.
    **/
   bool onlyLocalReferences() const;
 
@@ -796,6 +812,16 @@ public:
    */
   KHTMLPart *findFrame( const QString &f );
 
+  /**
+   * @internal
+   * Recursively finds the part containing the frame with name @p f 
+   * and checks if it is accessible by @p callingPart
+   * Returns 0L if no suitable frame can't be found.
+   * Returns parent part if a suitable frame was found and
+   * frame info in @p *childFrame
+   */
+  KHTMLPart *findFrameParent( KParts::ReadOnlyPart *callingPart, const QString &f, khtml::ChildFrame **childFrame=0 );
+
   /**
    * Return the current frame (the one that has focus)
    * Not necessarily a direct child of ours, framesets can be nested.
@@ -1287,6 +1313,11 @@ private slots:
    */
   void slotJobDone( KIO::Job* );
 
+  /*
+   * @internal
+   */
+  void slotUserSheetStatDone( KIO::Job* );
+
   /*
    * @internal
    */
@@ -1348,6 +1379,8 @@ private:
 
   bool restoreURL( const KURL &url );
   void emitSelectionChanged();
+  // Returns whether callingHtmlPart may access this part
+  bool checkFrameAccess(KHTMLPart *callingHtmlPart);
   bool openURLInFrame( const KURL &url, const KParts::URLArgs &urlArgs );
   void startAutoScroll();
   void stopAutoScroll();
@@ -1406,7 +1439,7 @@ private:
   DOM::DocumentImpl *xmlDocImpl() const;
   khtml::ChildFrame *frame( const QObject *obj );
 
-  khtml::ChildFrame *recursiveFrameRequest( const KURL &url, const KParts::URLArgs &args, bool callParent = true );
+  khtml::ChildFrame *recursiveFrameRequest( KHTMLPart *callingHtmlPart, const KURL &url, const KParts::URLArgs &args, bool callParent = true );
 
   bool checkLinkSecurity( const KURL &linkURL,const QString &message = QString::null, const QString &button = QString::null );
   QVariant executeScript( const QString& filename, int baseLine, const DOM::Node &n, const QString& script );
@@ -1453,6 +1486,8 @@ private:
 
   void emitCaretPositionChanged(const DOM::Node &node, long offset);
 
+  void setDebugScript( bool enable );
+  
   KHTMLPartPrivate *d;
   friend class KHTMLPartPrivate;
 };
