@@ -32,6 +32,7 @@
 
 #include <qlineedit.h>
 #include <kcompletion.h>
+#include <kdemacros.h>
 
 class QPopupMenu;
 
@@ -41,9 +42,9 @@ class KURL;
 /**
  * An enhanced QLineEdit widget for inputting text.
  *
- * @sect Detail
+ * \b Detail \n
  *
- * This widget inherits from @ref QLineEdit and implements the following
+ * This widget inherits from QLineEdit and implements the following
  * additional functionalities: a completion object that provides both
  * automatic and manual text completion as well as multiple match iteration
  * features, configurable key-bindings to activate these features and a
@@ -51,70 +52,75 @@ class KURL;
  * modes on the fly based on their preference.
  *
  * To support these new features KLineEdit also emits a few more
- * additional signals.  These are: @ref completion( const QString& ),
- * textRotation( KeyBindingType ), and @ref returnPressed( const QString& ).
+ * additional signals.  These are: completion( const QString& ),
+ * textRotation( KeyBindingType ), and returnPressed( const QString& ).
  * The completion signal can be connected to a slot that will assist the
  * user in filling out the remaining text.  The text rotation signal is
  * intended to be used to iterate through the list of all possible matches
  * whenever there is more than one match for the entered text.  The
- * @p returnPressed( const QString& ) signals are the same as @ref QLineEdit's
+ * @p returnPressed( const QString& ) signals are the same as QLineEdit's
  * except it provides the current text in the widget as its argument whenever
  * appropriate.
  *
  * This widget by default creates a completion object when you invoke
- * the @ref completionObject( bool ) member function for the first time or
- * use @ref setCompletionObject( KCompletion*, bool ) to assign your own
+ * the completionObject( bool ) member function for the first time or
+ * use setCompletionObject( KCompletion*, bool ) to assign your own
  * completion object.  Additionally, to make this widget more functional,
  * KLineEdit will by default handle the text rotation and completion
  * events internally when a completion object is created through either one
  * of the methods mentioned above.  If you do not need this functionality,
- * simply use @ref KCompletionBase::setHandleSignals( bool ) or set the
- * boolean parameter in the above functions to FALSE.
+ * simply use KCompletionBase::setHandleSignals( bool ) or set the
+ * boolean parameter in the above functions to false.
  *
  * The default key-bindings for completion and rotation is determined
- * from the global settings in @ref KStdAccel.  These values, however,
- * can be overriden locally by invoking @ref KCompletionBase::setKeyBinding().
+ * from the global settings in KStdAccel.  These values, however,
+ * can be overridden locally by invoking KCompletionBase::setKeyBinding().
  * The values can easily be reverted back to the default setting, by simply
- * calling @ref useGlobalSettings(). An alternate method would be to default
- * individual key-bindings by usning @ref setKeyBinding() with the default
+ * calling useGlobalSettings(). An alternate method would be to default
+ * individual key-bindings by usning setKeyBinding() with the default
  * second argument.
  *
- * NOTE that if the @p EchoMode for this widget is set to something other
- * than @p QLineEdit::Normal, the completion mode will always be defaulted
- * to @ref KGlobalSettings::CompletionNone.  This is done purposefully to guard
- * against protected entries such as passwords being cached in @ref KCompletion's
- * list. Hence, if the @p EchoMode is not QLineEdit::Normal, the completion
- * mode is automatically disabled.
+ * If @p EchoMode for this widget is set to something other than @p QLineEdit::Normal, 
+ * the completion mode will always be defaulted to KGlobalSettings::CompletionNone.  
+ * This is done purposefully to guard against protected entries such as passwords being
+ * cached in KCompletion's list. Hence, if the @p EchoMode is not QLineEdit::Normal, the
+ * completion mode is automatically disabled.
  *
- * @sect Usage
+ * A read-only KLineEdit will have the same background color as a 
+ * disabled KLineEdit, but its foreground color will be the one used 
+ * for the read-write mode. This differs from QLineEdit's implementation
+ * and is done to give visual distinction between the three different modes: 
+ * disabled, read-only, and read-write.
+ *
+ * \b Usage \n
  *
  * To enable the basic completion feature :
  *
- * <pre>
+ * \code
  * KLineEdit *edit = new KLineEdit( this, "mywidget" );
  * KCompletion *comp = edit->completionObject();
  * // Connect to the return pressed signal - optional
  * connect(edit,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&));
- * </pre>
+ * \endcode
  *
  * To use a customized completion objects or your
  * own completion object :
  *
- * <pre>
+ * \code
  * KLineEdit *edit = new KLineEdit( this,"mywidget" );
  * KURLCompletion *comp = new KURLCompletion();
  * edit->setCompletionObject( comp );
  * // Connect to the return pressed signal - optional
  * connect(edit,SIGNAL(returnPressed(const QString&)),comp,SLOT(addItem(const QString&));
- * </pre>
+ * \endcode
  *
  * Note that you have to either delete the allocated completion object
  * when you don't need it anymore, or call
  * setAutoDeleteCompletionObject( true );
  *
- * @sect Miscellaneous function calls :
+ * <b>Miscellaneous function calls :</b>\n
  *
- * <pre>
+ * \code
  * // Tell the widget not to handle completion and
  * // iteration internally.
  * edit->setHandleSignals( false );
@@ -127,7 +133,7 @@ class KURL;
  * edit->disableSignals();
  * // Default the key-bindings to system settings.
  * edit->useGlobalKeyBindings();
- * </pre>
+ * \endcode
  *
  * @short An enhanced single line input widget.
  * @author Dawit Alemayehu <adawit@kde.org>
@@ -140,6 +146,8 @@ class KLineEdit : public QLineEdit, public KCompletionBase
     Q_OBJECT
     Q_PROPERTY( bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled )
     Q_PROPERTY( bool urlDropsEnabled READ isURLDropsEnabled WRITE setURLDropsEnabled )
+    Q_PROPERTY( bool trapEnterKeyEvent READ trapReturnKey WRITE setTrapReturnKey )
+    Q_PROPERTY( bool enableSqueezedText READ isSqueezedTextEnabled WRITE setEnableSqueezedText )
 
 public:
 
@@ -156,7 +164,6 @@ public:
     /**
      * Constructs a KLineEdit object with a parent and a name.
      *
-     * @param string Text to be shown in the edit widget.
      * @param parent The parent object of this widget.
      * @param name The name of this widget.
      */
@@ -168,7 +175,7 @@ public:
     virtual ~KLineEdit ();
 
     /**
-     * Sets @p url into the lineedit. It uses @ref KURL::prettyURL() so
+     * Sets @p url into the lineedit. It uses KURL::prettyURL() so
      * that the url is properly decoded for displaying.
      */
     void setURL( const KURL& url );
@@ -176,21 +183,21 @@ public:
     /**
      * Puts the text cursor at the end of the string.
      *
-     * This method is deprecated.  Use @ref QLineEdit::end()
+     * This method is deprecated.  Use QLineEdit::end()
      * instead.
      *
      * @deprecated
-     * @ref QLineEdit::end()
+     * QLineEdit::end()
      */
     void cursorAtEnd() { end( false ); }
 
     /**
-     * Re-implemented from @ref KCompletionBase for internal reasons.
+     * Re-implemented from KCompletionBase for internal reasons.
      *
      * This function is re-implemented in order to make sure that
      * the EchoMode is acceptable before we set the completion mode.
      *
-     * See @ref KCompletionBase::setCompletionMode
+     * See KCompletionBase::setCompletionMode
      */
     virtual void setCompletionMode( KGlobalSettings::Completion mode );
 
@@ -200,11 +207,11 @@ public:
     * Note that when this function is invoked with its argument
     * set to @p true, then both the context menu and the completion
     * menu item are enabled.  If you do not want to the completion
-    * item to be visible simply invoke @ref hideModechanger() right
+    * item to be visible simply invoke hideModechanger() right
     * after calling this method.  Also by default, the context
     * menu is automatically created if this widget is editable. Thus
     * you need to call this function with the argument set to false
-    * if you do not want this behaviour.
+    * if you do not want this behavior.
     *
     * @param showMenu If @p true, show the context menu.
     */
@@ -218,7 +225,7 @@ public:
     /**
      * Enables/Disables handling of URL drops. If enabled and the user
      * drops an URL, the decoded URL will be inserted. Otherwise the default
-     * behaviour of QLineEdit is used, which inserts the encoded URL.
+     * behavior of QLineEdit is used, which inserts the encoded URL.
      *
      * @param enable If @p true, insert decoded URLs
      */
@@ -231,7 +238,7 @@ public:
 
     /**
      * By default, KLineEdit recognizes @p Key_Return and @p Key_Enter and emits
-     * the @ref returnPressed() signals, but it also lets the event pass,
+     * the returnPressed() signals, but it also lets the event pass,
      * for example causing a dialog's default-button to be called.
      *
      * Call this method with @p trap = @p true to make @p KLineEdit stop these
@@ -252,13 +259,12 @@ public:
     /**
      * Re-implemented for internal reasons.  API not affected.
      *
-     * @reimplemented
      */
     virtual bool eventFilter( QObject *, QEvent * );
 
     /**
      * @returns the completion-box, that is used in completion mode
-     * @ref KGlobalSettings::CompletionPopup.
+     * KGlobalSettings::CompletionPopup.
      * This method will create a completion-box if none is there, yet.
      *
      * @param create Set this to false if you don't want the box to be created
@@ -276,6 +282,34 @@ public:
      */
     virtual void copy() const;
 
+    /**
+     * Enable text squeezing in read-only line edits if text too long.
+     * This only works when the widget is in read-only mode.
+     *
+     * Note that once text squeezing is enabled, @ref QLineEdit::text
+     * and @ref QLineEdit::displayText return the squeezed text. If
+     * you want the original text, use @ref originalText.
+     *
+     * @since 3.2
+     */    
+    void setEnableSqueezedText( bool enable );
+    
+    /**
+     * Returns true if text squeezing is enabled.
+     * This is only valid when the widget is in read-only mode.
+     * @since 3.2
+     */
+    bool isSqueezedTextEnabled() const;
+
+    /**
+     * Returns the original text if text squeezing is enabled and
+     * the widget is in read-only mode. Otherwise, it returns the 
+     * same thing as @ref QLineEdit::text(). 
+     * 
+     * @since 3.2
+     */
+    QString originalText() const;
+
 signals:
 
     /**
@@ -312,8 +346,8 @@ signals:
      *
      * The argument indicates which key-binding was pressed.
      * In KLineEdit's case this can be either one of two values:
-     * @ref PrevCompletionMatch or @ref NextCompletionMatch. See
-     * @ref KCompletionBase::setKeyBinding for details.
+     * PrevCompletionMatch or NextCompletionMatch. See
+     * KCompletionBase::setKeyBinding for details.
      *
      * Note that this signal is @em not emitted if the completion
      * mode is set to @p KGlobalSettings::CompletionNone or @p echoMode() is @em not  normal.
@@ -336,9 +370,9 @@ signals:
      * provided through since it is created and deleted
      * on demand.
      *
-     * @param the context menu about to be displayed
+     * @param p the context menu about to be displayed
      */
-    void aboutToShowContextMenu( QPopupMenu* );
+    void aboutToShowContextMenu( QPopupMenu * p );
 
 public slots:
 
@@ -357,15 +391,15 @@ public slots:
      *
      * @param type The key-binding invoked.
      */
-    void rotateText( KCompletionBase::KeyBindingType /* type */ );
+    void rotateText( KCompletionBase::KeyBindingType type );
 
     /**
-     * See @ref KCompletionBase::setCompletedText.
+     * See KCompletionBase::setCompletedText.
      */
     virtual void setCompletedText( const QString& );
 
     /**
-     * Sets @p items into the completion-box if @ref completionMode() is
+     * Sets @p items into the completion-box if completionMode() is
      * CompletionPopup. The popup will be shown immediately.
      */
     void setCompletedItems( const QStringList& items );
@@ -383,6 +417,12 @@ public slots:
      */
     void setSqueezedText( const QString &text);
 
+    /**
+     * Re-implemented to enable text squeezing. API is not affected.
+     */
+    virtual void setText ( const QString& );
+    
+    
 protected slots:
 
     /**
@@ -401,47 +441,54 @@ protected slots:
      */
     void slotCancelled() {}
 
+    /**
+     * Resets the current displayed text. 
+     * Call this function to revert a text completion if the user 
+     * cancels the request. Mostly applies to popup completions.
+     */
+    void userCancelled(const QString & cancelText);
+
 protected:
 
     /**
     * Re-implemented for internal reasons.  API not affected.
     *
-    * See @ref QLineEdit::resizeEvent().
+    * See QLineEdit::resizeEvent().
     */
     virtual void resizeEvent( QResizeEvent * );
 
     /**
     * Re-implemented for internal reasons.  API not affected.
     *
-    * See @ref QLineEdit::keyPressEvent().
+    * See QLineEdit::keyPressEvent().
     */
     virtual void keyPressEvent( QKeyEvent * );
 
     /**
     * Re-implemented for internal reasons.  API not affected.
     *
-    * See @ref QLineEdit::mousePressEvent().
+    * See QLineEdit::mousePressEvent().
     */
     virtual void mousePressEvent( QMouseEvent * );
 
     /**
     * Re-implemented for internal reasons.  API not affected.
     *
-    * See @ref QWidget::mouseDoubleClickEvent().
+    * See QWidget::mouseDoubleClickEvent().
     */
     virtual void mouseDoubleClickEvent( QMouseEvent * );
 
     /**
     * Re-implemented for internal reasons.  API not affected.
     *
-    * See @ref QLineEdit::createPopupMenu().
+    * See QLineEdit::createPopupMenu().
     */
     virtual QPopupMenu *createPopupMenu();
 
     /**
     * Re-implemented to handle URI drops.
     *
-    * See @ref QLineEdit::dropEvent().
+    * See QLineEdit::dropEvent().
     */
     virtual void dropEvent( QDropEvent * );
 
@@ -455,6 +502,13 @@ protected:
     */
     virtual void setCompletedText( const QString& /*text*/, bool /*marked*/ );
 
+
+    /**
+     * Sets the widget in userSelection mode or in automatic completion
+     * selection mode. This changes the colors of selections.
+     */
+    void setUserSelection( bool userSelection );
+
     /**
      * Reimplemented for internal reasons, the API is not affected.
      */
@@ -464,19 +518,21 @@ protected:
 private slots:
     void completionMenuActivated( int id );
     void tripleClickTimeout();  // resets possibleTripleClick
+    void slotRestoreSelectionColors();
     void setTextWorkaround( const QString& text );
 
 private:
+
     // Constants that represent the ID's of the popup menu.
-    // TODO: See if we can replace this mess with KActionMenu
-    // in the future though it's working lovely.
-    enum MenuID {
+    enum MenuID
+    {
         Default = 42,
         NoCompletion,
         AutoCompletion,
         ShellCompletion,
         PopupCompletion,
-        SemiAutoCompletion
+        ShortAutoCompletion,
+        PopupAutoCompletion
     };
 
     /**
@@ -495,6 +551,12 @@ private:
      */
     bool overrideAccel (const QKeyEvent* e);
 
+    /**
+     * Properly sets the squeezed text whenever the widget is 
+     * created or resized.
+     */
+    void setSqueezedText ();
+
     bool m_bEnableMenu;
 
     bool possibleTripleClick;  // set in mousePressEvent, deleted in tripleClickTimeout
