@@ -27,6 +27,7 @@
 #include <qptrlist.h>
 #include <qdatastream.h>
 #include <qstringlist.h>
+#include <qpair.h>
 
 #include <kparts/part.h>
 #include <kparts/event.h>
@@ -79,7 +80,7 @@ struct URLArgs
    */
   int xOffset;
   /**
-   * @p yOffset vertical scrolling position, @ref xOffset.
+   * @p yOffset vertical scrolling position, xOffset.
    */
   int yOffset;
   /**
@@ -91,6 +92,7 @@ struct URLArgs
    * KHTML-specific field, contents of the HTTP POST data.
    */
   QByteArray postData;
+  
   /**
    * KHTML-specific field, header defining the type of the POST data.
    */
@@ -104,6 +106,7 @@ struct URLArgs
    * for the next openURL.
    */
   void setDoPost( bool enable );
+  
   /**
    * KHTML-specific field, whether to do a POST instead of a GET,
    * for the next openURL.
@@ -143,12 +146,16 @@ struct URLArgs
   bool trustedSource;
 
   /**
-   * @internal Do not use.
+   * @return true if the request was a result of a META refresh/redirect request or
+   * HTTP redirect.
    */
   bool redirectedRequest () const;
 
   /**
-   * @internal Do not use.
+   * Set the redirect flag to indicate URL is a result of either a META redirect
+   * or HTTP redirect.
+   *
+   * @param redirected
    */
   void setRedirectedRequest(bool redirected);
 
@@ -246,7 +253,7 @@ class BrowserExtensionPrivate;
   * @li @p rename : Rename item in place.
   * @li @p trash : Move selected items to trash.
   * @li @p del : Delete selected items (couldn't call it delete!).
-  * @li @p shred : Shred selected items (secure deletion).
+  * @li @p shred : Shred selected items (secure deletion) - DEPRECATED.
   * @li @p properties : Show file/document properties.
   * @li @p editMimeType : show file/document's mimetype properties.
   *
@@ -262,7 +269,7 @@ class BrowserExtensionPrivate;
   *
   *
   * The selection-dependent actions are disabled by default and the view should
-  * enable them when the selection changes, emitting @ref enableAction().
+  * enable them when the selection changes, emitting enableAction().
   *
   * The normal actions do not depend on the selection.
   * You need to enable 'print' when printing is possible - you can even do that
@@ -292,6 +299,23 @@ public:
 
   virtual ~BrowserExtension();
 
+  typedef uint PopupFlags;
+
+  /**
+   * Set of flags passed via the popupMenu signal, to ask for some items in the popup menu.
+   * DefaultPopupItems: default value, no additional menu item
+   * ShowNavigationItems: show "back" and "forward" (usually done when clicking the background of the view, but not an item)
+   * ShowUp: show "up" (same thing, but not over e.g. HTTP). Requires ShowNavigationItems.
+   * ShowReload: show "reload" (usually done when clicking the background of the view, but not an item)
+   * ShowBookmark: show "add to bookmarks" (usually not done on the local filesystem)
+   * ShowCreateDirectory: show "create directory" (usually only done on the background of the view, or
+   *                      in hierarchical views like directory trees, where the new dir would be visible)
+   */
+  enum { DefaultPopupItems=0x0000, ShowNavigationItems=0x0001,
+         ShowUp=0x0002, ShowReload=0x0004, ShowBookmark=0x0008,
+         ShowCreateDirectory=0x0010 };
+
+
   /**
    * Set the parameters to use for opening the next URL.
    * This is called by the "hosting" application, to pass parameters to the part.
@@ -323,7 +347,7 @@ public:
    * Used by the browser to save the current state of the view
    * (in order to restore it if going back in navigation).
    *
-   * If you want to save additionnal properties, reimplement it
+   * If you want to save additional properties, reimplement it
    * but don't forget to call the parent method (probably first).
    */
   virtual void saveState( QDataStream &stream );
@@ -332,14 +356,14 @@ public:
    * Used by the browser to restore the view in the state
    * it was when we left it.
    *
-   * If you saved additionnal properties, reimplement it
+   * If you saved additional properties, reimplement it
    * but don't forget to call the parent method (probably first).
    */
   virtual void restoreState( QDataStream &stream );
 
   /**
    * Returns whether url drop handling is enabled.
-   * See @ref setURLDropHandlingEnabled for more information about this
+   * See setURLDropHandlingEnabled for more information about this
    * property.
    */
   bool isURLDropHandlingEnabled() const;
@@ -380,19 +404,19 @@ public:
    * iterator.
    * Checking if the extension implements a certain slot can be done like this:
    *
-   * <pre>
+   * \code
    *   extension->metaObject()->slotNames().contains( actionName + "()" )
-   * </pre>
+   * \endcode
    *
    * (note that @p actionName is the iterator's key value if already
    *  iterating over the action slot map, returned by this method)
    *
    * Connecting to the slot can be done like this:
    *
-   * <pre>
+   * \code
    *   connect( yourObject, SIGNAL( yourSignal() ),
    *            extension, mapIterator.data() )
-   * </pre>
+   * \endcode
    *
    * (where "mapIterator" is your QMap<QCString,QCString> iterator)
    */
@@ -410,6 +434,11 @@ public:
    */
   static BrowserExtension *childObject( QObject *obj );
 
+  /**
+   * Asks the hosting browser to perform a paste.
+   * @since 3.2
+   */
+  void pasteRequest(); 
 // KDE invents support for public signals...
 #undef signals
 #define signals public
@@ -427,7 +456,7 @@ signals:
    * Asks the host (browser) to open @p url.
    * To set a reload, the x and y offsets, the service type etc., fill in the
    * appropriate fields in the @p args structure.
-   * Hosts should not connect to this signal but to @ref openURLRequestDelayed.
+   * Hosts should not connect to this signal but to openURLRequestDelayed.
    */
   void openURLRequest( const KURL &url, const KParts::URLArgs &args = KParts::URLArgs() );
 
@@ -441,18 +470,18 @@ signals:
 
   /**
    * Tells the hosting browser that the part opened a new URL (which can be
-   * queried via @ref KParts::Part::url().
+   * queried via KParts::Part::url().
    *
    * This helps the browser to update/create an entry in the history.
-   * The part may @em not emit this signal together with @ref openURLRequest().
-   * Emit @ref openURLRequest() if you want the browser to handle a URL the user
+   * The part may @em not emit this signal together with openURLRequest().
+   * Emit openURLRequest() if you want the browser to handle a URL the user
    * asked to open (from within your part/document). This signal however is
    * useful if you want to handle URLs all yourself internally, while still
    * telling the hosting browser about new opened URLs, in order to provide
    * a proper history functionality to the user.
    * An example of usage is a html rendering component which wants to emit
    * this signal when a child frame document changed its URL.
-   * Conclusion: you probably want to use @ref openURLRequest() instead.
+   * Conclusion: you probably want to use openURLRequest() instead.
    */
   void openURLNotify();
 
@@ -469,7 +498,7 @@ signals:
   /**
    * Asks the hosting browser to open a new window for the given @p url.
    *
-   * The @p args argument is optional additionnal information for the
+   * The @p args argument is optional additional information for the
    * browser,
    * @see KParts::URLArgs
    */
@@ -486,11 +515,11 @@ signals:
                         const KParts::WindowArgs &windowArgs, KParts::ReadOnlyPart *&part );
 
   /**
-   * Since the part emits the jobid in the @ref started() signal,
+   * Since the part emits the jobid in the started() signal,
    * progress information is automatically displayed.
    *
-   * However, if you don't use a @ref KIO::Job in the part,
-   * you can use @ref loadingProgress() and @ref speedProgress()
+   * However, if you don't use a KIO::Job in the part,
+   * you can use loadingProgress() and speedProgress()
    * to display progress information.
    */
   void loadingProgress( int percent );
@@ -515,6 +544,8 @@ signals:
    */
   void popupMenu( KXMLGUIClient *client, const QPoint &global, const KFileItemList &items );
 
+  void popupMenu( KXMLGUIClient *client, const QPoint &global, const KFileItemList &items, const KParts::URLArgs &args, KParts::BrowserExtension::PopupFlags i );
+
   /**
    * Emit this to make the browser show a standard popup menu
    * at the point @p global for the given @p url.
@@ -539,6 +570,19 @@ signals:
                   const QPoint &global, const KURL &url,
                   const QString &mimeType, mode_t mode = (mode_t)-1 );
 
+  /**
+   * Emit this to make the browser show a standard popup menu
+   * at the point @p global for the given @p url.
+   *
+   * Give as much information
+   * about this URL as possible, like @p args.mimeType and the file type
+   * (@p mode: S_IFREG, S_IFDIR...)
+   * The GUI described by @p client is being merged with the popupmenu of the host
+   */
+  void popupMenu( KXMLGUIClient *client,
+                  const QPoint &global, const KURL &url,
+                  const KParts::URLArgs &args, KParts::BrowserExtension::PopupFlags i, mode_t mode = (mode_t)-1 );
+
   /**
    * Inform the hosting application about the current selection.
    * Used when a set of files/URLs is selected (with full information
@@ -562,6 +606,23 @@ signals:
    */
   void mouseOverInfo( const KFileItem* item );
 
+  /**
+   * Ask the hosting application to add a new HTML (aka Mozilla/Netscape)
+   * SideBar entry.
+   */
+  void addWebSideBar(const KURL &url, const QString& name);
+
+  /**
+   * Ask the hosting application to move the top level widget.
+   */
+  void moveTopLevelWidget( int x, int y );
+
+  /**
+   * Ask the hosting application to resize the top level widget.
+   */
+  void resizeTopLevelWidget( int w, int h );
+
+
 private slots:
   void slotCompleted();
   void slotOpenURLRequest( const KURL &url, const KParts::URLArgs &args );
@@ -621,7 +682,7 @@ public:
 
   /**
    * Opens the given url in a hosted child frame. The frame name is specified in the
-   * frameName variable in the urlArgs argument structure (see @ref KParts::URLArgs ) .
+   * frameName variable in the urlArgs argument structure (see KParts::URLArgs ) .
    */
   virtual bool openURLInFrame( const KURL &url, const KParts::URLArgs &urlArgs );
 
